import { Component, OnInit } from '@angular/core';
import { Passenger } from '../../interfaces/passenger.interface';
import { TicketType } from '../../interfaces/ticket-type.interface';
import { FlightClass } from '../../interfaces/flight-class.interface';
import { TableModel } from 'src/app/shared/interfaces/table-model.interface';
import { PassengerService } from '../../services/passenger.service';
import { TicketTypeService } from '../../services/ticket-type.service';
import { TicketClassService } from '../../services/ticket-class.service';

@Component({
  selector: 'agent-base-information',
  templateUrl: './base-information.component.html',
  styleUrls: ['./base-information.component.css']
})
export class BaseInformationComponent implements OnInit {

  public passengerModel: TableModel[] = [
    {
      name: 'id',
      title: '#'
    },
    {
      name: 'name',
      title: 'Nombre'
    },
    {
      name: 'secondName',
      title: 'Segundo Nombre'
    },
    {
      name: 'lastname',
      title: 'Apellido'
    },
    {
      name: 'email',
      title: 'Correo'
    },
    {
      name: 'phone',
      title: 'Teléfono'
    }
  ];

  constructor(private passengersService: PassengerService,
    private ticketTypesService: TicketTypeService,
    private ticketClassService: TicketClassService) { }

  ngOnInit(): void {
    this.passengersService.getAll()
      .subscribe(passengers => this.passengers = passengers);

    this.ticketTypesService.getAll()
      .subscribe(ticketTypes => this.ticketTypes = ticketTypes);

    this.ticketClassService.getAll()
      .subscribe(flightClass => this.flightClass = flightClass);
  }

  public passengers: Passenger[] = [];

  public ticketTypes: TicketType[] = [];

  public flightClass: FlightClass[] = [];

  public passengerSelected?: Passenger;

  get passengerSelectedName(): string {
    return this.passengerSelected ? `${this.passengerSelected.name} ${this.passengerSelected.lastname}` : '';
  }

  onSelectedPassenger(passenger: Passenger): void {
    this.passengerSelected = passenger;
  }
}
