import { Component, OnInit } from '@angular/core';
import { FormGroup } from '@angular/forms';
import { ActivatedRoute } from '@angular/router';
import { PassengerService } from '../../services/passenger.service';
import { EMPTY_PASSENGER, Passenger } from '../../interfaces/passenger.interface';
import { PASSENGER_VALIDATORS, getPassengerValidatorLenght } from '../../validators/passenger.validator';
import { Location } from '@angular/common';

@Component({
  selector: 'app-passenger-add',
  templateUrl: './passenger-add.component.html',
  styleUrls: ['./passenger-add.component.css']
})
export class PassengerAddComponent implements OnInit {

  public passengerForm: FormGroup = PASSENGER_VALIDATORS;
  public passengerId?: number;

  constructor(
    private location: Location,
    private activatedRoute: ActivatedRoute,
    private passengerService: PassengerService) { }

  ngOnInit(): void {
    this.activatedRoute.params.subscribe(param => {
      if (param['id']) {
        this.passengerService.getById(param['id'])
        .subscribe(passenger => {
          this.buildForm(passenger);
          this.passengerId = param['id'];
        });
      } else this.buildForm(EMPTY_PASSENGER);
    });
  }

  buildForm(passenger: Passenger): void {
    this.passengerForm.get('name')?.setValue(passenger.name || '');
    this.passengerForm.get('secondName')?.setValue(passenger.secondName || '');
    this.passengerForm.get('lastname')?.setValue(passenger.lastname || '');
    this.passengerForm.get('country')?.setValue(passenger.country || '');
    this.passengerForm.get('city')?.setValue(passenger.city || '');
    this.passengerForm.get('address')?.setValue(passenger.address || '');
    this.passengerForm.get('phone')?.setValue(passenger.phone || '');
    this.passengerForm.get('email')?.setValue(passenger.email || '');
    this.passengerForm.get('password')?.setValue(passenger.password || '');
  }

  getPassengerValidatorLenght(field: string) {
    return getPassengerValidatorLenght(field);
  }

  onSave():void {
    this.passengerForm.markAllAsTouched();
    if (this.passengerId) {
      this.passengerService.edit(this.passengerId, this.passengerForm.value)
        .subscribe(() => {
          this.passengerForm.reset();
          this.location.back();
        });
    } else {
      this.passengerService.save(this.passengerForm.value)
        .subscribe(() => {
          this.passengerForm.reset();
          this.location.back();
        });
    }
  }
}
